#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITS_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/simd/bits.hpp>

#endif
